@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -72,8 +72,6 @@ from trackme_libs import (
     trackme_register_tenant_object_summary,
     run_splunk_search,
     trackme_handler_events,
-    trackme_idx_for_tenant,
-    trackme_gen_state,
 )
 
 # import trackme libs utils
@@ -82,8 +80,6 @@ from trackme_libs_utils import remove_leading_spaces, decode_unicode
 # import trackme libs croniter
 from trackme_libs_croniter import cron_to_seconds
 
-# import trackme libs scoring
-from trackme_libs_scoring import trackme_scoring_gen_metrics
 
 @Configuration(distributed=False)
 class SplkOutliersTracker(GeneratingCommand):
@@ -113,15 +109,6 @@ class SplkOutliersTracker(GeneratingCommand):
         validate=validators.Match("object", r"^.*$"),
     )
 
-    object_id = Option(
-        doc="""
-        **Syntax:** **object_id=****
-        **Description:** Optional, The value for object id.""",
-        require=False,
-        default="*",
-        validate=validators.Match("object_id", r"^.*$"),
-    )
-
     max_runtime = Option(
         doc="""
         **Syntax:** **max_runtime=****
@@ -131,19 +118,6 @@ class SplkOutliersTracker(GeneratingCommand):
         validate=validators.Match("object", r"^\d*$"),
     )
 
-    def _get_log_object_ref(self, object_value=None, object_id_value=None):
-        """Helper function to get object reference for logging (includes object_id when available)."""
-        object_id_ref = f'object_id="{object_id_value}"' if object_id_value else ""
-        object_ref = f'object="{object_value}"' if object_value else ""
-        if object_id_ref and object_ref:
-            return f'{object_id_ref}, {object_ref}'
-        elif object_id_ref:
-            return object_id_ref
-        elif object_ref:
-            return object_ref
-        else:
-            return 'object="*"'
-
     force_run = Option(
         doc="""
         **Syntax:** **force_run=****
@@ -192,13 +166,6 @@ class SplkOutliersTracker(GeneratingCommand):
             f'vtenant_component_info="{json.dumps(vtenant_component_info, indent=2)}"'
         )
 
-        # Get the tenant indexes
-        tenant_indexes = trackme_idx_for_tenant(
-            self._metadata.searchinfo.session_key,
-            self._metadata.searchinfo.splunkd_uri,
-            self.tenant_id,
-        )        
-
         # check schema version migration state
         try:
             schema_version = int(vtenant_component_info["schema_version"])
@@ -270,9 +237,6 @@ class SplkOutliersTracker(GeneratingCommand):
             # counter
             count = 0
 
-            # scoring metrics records
-            scoring_metrics_records = []            
-
             # Get the session key
             session_key = self._metadata.searchinfo.session_key
 
@@ -323,41 +287,11 @@ class SplkOutliersTracker(GeneratingCommand):
                 f'max_runtime="{max_runtime}",  savedsearch_name="{report_name}", savedsearch_cron_schedule="{savedsearch_cron_schedule}", cron_exec_sequence_sec="{cron_exec_sequence_sec}"'
             )
 
-            # If object_id is provided, resolve it to object value for the macro
-            object_for_search = self.object
-            if self.object_id != "*" and self.object == "*":
-                # Query KVstore to get object value from object_id
-                try:
-                    query_string_filter = {
-                        "object_category": f"splk-{self.component}",
-                        "_key": self.object_id,
-                    }
-                    query_string = {"$and": [query_string_filter]}
-                    records_outliers_rules = collection_rule.data.query(
-                        query=json.dumps(query_string)
-                    )
-                    if records_outliers_rules:
-                        record_outliers_rules = records_outliers_rules[0]
-                        object_for_search = record_outliers_rules.get("object", "*")
-                        logging.debug(
-                            f'Resolved object_id="{self.object_id}" to object="{object_for_search}"'
-                        )
-                    else:
-                        logging.warning(
-                            f'Could not resolve object_id="{self.object_id}" to object value, using "*"'
-                        )
-                        object_for_search = "*"
-                except Exception as e:
-                    logging.error(
-                        f'Failed to resolve object_id="{self.object_id}" to object value, exception="{str(e)}", using "*"'
-                    )
-                    object_for_search = "*"
-
             # Define the search providing the list of entities which models need to be monitored
             if self.force_run == "False":
                 search_query = remove_leading_spaces(
                     f"""
-                    | `get_splk_outliers_entities("{self.tenant_id}", "{self.component}", "{object_for_search}")`
+                    | `get_splk_outliers_entities("{self.tenant_id}", "{self.component}", "{self.object}")`
                     | eval duration_since_last=if(isnum(last_exec_monitor), now()-last_exec_monitor, 0)
                     | where duration_since_last=0 OR duration_since_last>={splk_outliers_time_monitor_mlmodels_default}
                     | sort - duration_since_last
@@ -367,7 +301,7 @@ class SplkOutliersTracker(GeneratingCommand):
             else:
                 search_query = remove_leading_spaces(
                     f"""
-                    | `get_splk_outliers_entities("{self.tenant_id}", "{self.component}", "{object_for_search}")`
+                    | `get_splk_outliers_entities("{self.tenant_id}", "{self.component}", "{self.object}")`
                     | eval duration_since_last=if(isnum(last_exec_monitor), now()-last_exec_monitor, 0)
                     | sort - duration_since_last
                 """
@@ -428,7 +362,6 @@ class SplkOutliersTracker(GeneratingCommand):
                         # Get the current record
                         # Notes: the record is returned as an array, as we search for a specific record, we expect one record only
                         key = None
-                        rules_key = None  # Store rules key for logging purposes
 
                         try:
                             records_outliers_rules = collection_rule.data.query(
@@ -436,17 +369,14 @@ class SplkOutliersTracker(GeneratingCommand):
                             )
                             record_outliers_rules = records_outliers_rules[0]
                             key = record_outliers_rules.get("_key")
-                            rules_key = key  # Store for logging
 
                         except Exception as e:
                             key = None
-                            rules_key = None
                             record_outliers_rules = None
 
                         # if no records, log a warning message and break
                         if not key:
-                            object_ref = self._get_log_object_ref(object_value=self.object)
-                            msg = f'tenant_id="{self.tenant_id}", object_category="splk-{self.component}", {object_ref} outliers rules record cannot be found or are not yet available for this entity.'
+                            msg = f'tenant_id="{self.tenant_id}", object_category="splk-{self.component}", object="{self.object}" outliers rules record cannot be found or are not yet available for this entity.'
                             logging.warn(msg)
                             break
 
@@ -528,31 +458,20 @@ class SplkOutliersTracker(GeneratingCommand):
                                                 f'kpi_metric_name="{kpi_metric_name}"'
                                             )
 
-                                            # retrieve the score from the model configuration
-                                            try:
-                                                score = int(model_config.get("score", 36))
-                                            except (ValueError, TypeError):
-                                                score = 36
-
                                             # Set the initial state for that model
                                             isOutlier = 0
                                             isOutlierReason = "None"
 
-                                            # Set the search - use object_id if available, otherwise fall back to object
-                                            if key:
-                                                object_param = f'object_id="{key}"'
-                                            else:
-                                                object_param = f'object="{object_value}"'
-                                            
+                                            # Set the search
                                             model_render_search = remove_leading_spaces(
                                                 f"""\
-                                                | trackmesplkoutliersrender tenant_id="{self.tenant_id}" component="{self.component}" {object_param} earliest="-24h" latest="now" model_id="{model_id}" allow_auto_train="{self.allow_auto_train}"
+                                                | trackmesplkoutliersrender tenant_id="{self.tenant_id}" component="{self.component}" object="{object_value}" earliest="-24h" latest="now" model_id="{model_id}" allow_auto_train="{self.allow_auto_train}"
                                                 | table _time, *, LowerBound, UpperBound
                                                 | sort 0 - _time | head 1
                                                 """
                                             )
                                             logging.info(
-                                                f'tenant_id="{self.tenant_id}", {self._get_log_object_ref(object_value=object_value, object_id_value=rules_key)}, model_id="{model_id}", Executing resulting search="{model_render_search}"'
+                                                f'tenant_id="{self.tenant_id}", object="{object_value}", model_id="{model_id}", Executing resulting search="{model_render_search}"'
                                             )
 
                                             # set kwargs
@@ -715,18 +634,6 @@ class SplkOutliersTracker(GeneratingCommand):
                                                                     ) * 100
                                                                     isOutlierReason = f'Outliers ML for kpi="{kpi_metric_name}", model_id="{model_id}", LowerBound="{round(float(LowerBound), 3)}" breached with kpi_metric_value="{round(float(kpi_metric_value), 3)}" at time="{time_outlier}", pct_decrease="{round(float(pct_decrease), 2)}"'
 
-                                                                    # add to scoring metrics records
-                                                                    scoring_metrics_records.append(
-                                                                        {
-                                                                            "tenant_id": self.tenant_id,
-                                                                            "object_id": key,
-                                                                            "object": object_value,
-                                                                            "object_category": self.component,
-                                                                            "score_source": f"lowerbound_outlier|model_id={model_id}",
-                                                                            "metrics_event": {"score": score, "pct_decrease": round(float(pct_decrease), 2)},
-                                                                        }
-                                                                    )
-
                                                             elif int(
                                                                 alert_upper_breached
                                                             ) == 1 and float(
@@ -761,18 +668,6 @@ class SplkOutliersTracker(GeneratingCommand):
                                                                     ) * 100
                                                                     isOutlierReason = f'Outliers ML for kpi="{kpi_metric_name}", model_id="{model_id}", UpperBound="{round(float(UpperBound), 3)}" breached with kpi_metric_value="{round(float(kpi_metric_value), 3)}" at time="{time_outlier}", pct_increase="{round(float(pct_increase), 2)}"'
 
-                                                                    # add to scoring metrics records
-                                                                    scoring_metrics_records.append(
-                                                                        {
-                                                                            "tenant_id": self.tenant_id,
-                                                                            "object_id": key,
-                                                                            "object": object_value,
-                                                                            "object_category": self.component,
-                                                                            "score_source": f"upperbound_outlier|model_id={model_id}",
-                                                                            "metrics_event": {"score": score, "pct_increase": round(float(pct_increase), 2)},
-                                                                        }
-                                                                    )
-
                                                             else:
                                                                 isOutlier = 0
                                                                 isOutlierReason = "No outliers anomalies were detected"
@@ -793,7 +688,7 @@ class SplkOutliersTracker(GeneratingCommand):
                                                                     )
 
                                             except Exception as e:
-                                                error_msg = f'tenant_id="{self.tenant_id}", object_category="{self.component}", {self._get_log_object_ref(object_value=object_value, object_id_value=rules_key)}, model_id="{model_id}", search has failed with the following exception="{str(e)}", search="{model_render_search}"'
+                                                error_msg = f'tenant_id="{self.tenant_id}", object_category="{self.component}", object="{object_value}", model_id="{model_id}", search has failed with the following exception="{str(e)}", search="{model_render_search}"'
                                                 logging.error(error_msg)
 
                                             # Performance timer
@@ -832,7 +727,7 @@ class SplkOutliersTracker(GeneratingCommand):
 
                                             # log info
                                             logging.info(
-                                                f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref(object_value=object_value, object_id_value=rules_key)}, model_summary="{json.dumps(model_summary, indent=4)}"'
+                                                f'tenant_id="{self.tenant_id}", component="{self.component}", object="{object_value}", model_summary="{json.dumps(model_summary, indent=4)}"'
                                             )
 
                                 # summary record for that entity
@@ -898,7 +793,7 @@ class SplkOutliersTracker(GeneratingCommand):
 
                                     except Exception as e:
                                         logging.error(
-                                            f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref(object_value=object_value, object_id_value=rules_key)}, failed to insert a new KVstore record with exception="{str(e)}"'
+                                            f'tenant_id="{self.tenant_id}", component="{self.component}", object="{object_value}", failed to insert a new KVstore record with exception="{str(e)}"'
                                         )
 
                                 else:
@@ -924,7 +819,7 @@ class SplkOutliersTracker(GeneratingCommand):
 
                                     except Exception as e:
                                         logging.error(
-                                            f'tenant_id="{self.tenant_id}", component="{self.component}", {self._get_log_object_ref(object_value=object_value, object_id_value=rules_key)}, failed to update a KVstore record with exception="{str(e)}"'
+                                            f'tenant_id="{self.tenant_id}", component="{self.component}", object="{object_value}", failed to update a KVstore record with exception="{str(e)}"'
                                         )
 
                         # Calculate the execution time for this iteration
@@ -1001,36 +896,6 @@ class SplkOutliersTracker(GeneratingCommand):
                             f'tenant_id="{self.tenant_id}", component=f"splk-{self.component}", could not send notification event, exception="{e}"'
                         )
 
-                    # call the scoring gen metrics function
-                    scoring_metrics_gen_start = time.time()
-                    try:
-                        scoring_metrics = trackme_scoring_gen_metrics(
-                            self.tenant_id,
-                            tenant_indexes.get("trackme_metric_idx"),
-                            scoring_metrics_records,
-                        )
-                        logging.info(
-                            f'context="scoring_gen_metrics", tenant_id="{self.tenant_id}", function trackme_scoring_gen_metrics success {scoring_metrics}, run_time={round(time.time()-scoring_metrics_gen_start, 3)}, no_entities={len(scoring_metrics_records)}'
-                        )
-                    except Exception as e:
-                        logging.error(
-                            f'context="scoring_gen_metrics", tenant_id="{self.tenant_id}", function trackme_scoring_gen_metrics failed with exception {str(e)}'
-                        )
-
-                    # also generate events for the score
-                    for score_event in scoring_metrics_records:
-                        try:
-                            trackme_gen_state(
-                                index=tenant_indexes.get("trackme_summary_idx"),
-                                sourcetype="trackme:score",
-                                source=f"trackme_{self.component}_outliers_mlmonitor_tracker_tenant_{self.tenant_id}",
-                                event=score_event,
-                            )
-                        except Exception as e:
-                            logging.error(
-                                f'tenant_id="{self.tenant_id}", component="{self.component}", failed to generate score state event, exception="{str(e)}"'
-                            )
-
                 else:
                     logging.info(
                         f'tenant_id="{self.tenant_id}" outliers tracker job successfully executed but there were no entities to be tracked at this time, status="success", run_time="{round(time.time() - start, 3)}", report="{str(report_name)}", entities_count="{str(count)}"'
