@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -97,7 +97,7 @@ class SplkOutliersExecutor(GeneratingCommand):
         **Description:** The component category.""",
         require=True,
         default=None,
-        validate=validators.Match("component", r"^(?:dsm|dhm|flx|fqm|wlk)$"),
+        validate=validators.Match("component", r"^(?:dsm|dhm|cim|flx|fqm|wlk)$"),
     )
 
     earliest = Option(
@@ -193,7 +193,7 @@ class SplkOutliersExecutor(GeneratingCommand):
         outliers_feature_enabled = True
 
         # Define the valid components
-        valid_components = {"dsm", "dhm", "flx", "fqm", "wlk"}
+        valid_components = {"dsm", "dhm", "flx", "fqm", "wlk", "cim"}
 
         # Construct the key dynamically
         key = f"mloutliers_{self.component}"
@@ -290,7 +290,7 @@ class SplkOutliersExecutor(GeneratingCommand):
             # note: do not allow crap entities, sometimes users get very fancy, entities with double quotes in the value
             # are not expected nor desirable, do not allow crap to get in
 
-            if self.component in ("dsm", "dhm", "flx", "fqm"):
+            if self.component in ("dsm", "dhm", "flx", "fqm", "cim"):
                 search_query = remove_leading_spaces(
                     f"""\
                         | inputlookup trackme_{self.component}_outliers_entity_rules_tenant_{self.tenant_id} where object_category="splk-{self.component}"
@@ -356,7 +356,10 @@ class SplkOutliersExecutor(GeneratingCommand):
                             break
 
                         # set the search depending on the component
-                        search_train = f'| trackmesplkoutlierstrain tenant_id="{self.tenant_id}" component="{self.component}" object="{item.get("object")}"'
+                        if self.component in ("dsm", "dhm", "flx", "fqm", "wlk"):
+                            search_train = f'| trackmesplkoutlierstrain tenant_id="{self.tenant_id}" component="{self.component}" object="{item.get("object")}"'
+                        elif self.component in ("cim"):
+                            search_train = f'| trackmesplkoutlierscimtrain tenant_id="{self.tenant_id}" component="{self.component}" object="{item.get("object")}" cim_field="{item.get("cim_field")}"'
 
                         # append to our list
                         searches_toprocess.append(
@@ -530,7 +533,7 @@ class SplkOutliersExecutor(GeneratingCommand):
                             "object_category": f"splk-{self.component}",
                             "handler": f"trackme_{self.component}_outliers_mltrain_tracker_tenant_{self.tenant_id}",
                             "handler_message": "Entity was trained for ML Outliers.",
-                            "handler_troubleshoot_search": f"index=_internal (sourcetype=trackme:custom_commands:trackmesplkoutlierstrain) tenant_id={self.tenant_id} object=\"{object_record.get('object')}\"",
+                            "handler_troubleshoot_search": f"index=_internal (sourcetype=trackme:custom_commands:trackmesplkoutlierstrain OR sourcetype=trackme:custom_commands:trackmesplkoutlierscimtrain) tenant_id={self.tenant_id} object=\"{object_record.get('object')}\"",
                             "handler_time": time.time(),
                         }
                     )
