@@ -14,6 +14,7 @@ __status__ = "PRODUCTION"
 import os
 import sys
 import re
+import uuid
 
 # splunk home
 splunkhome = os.environ["SPLUNK_HOME"]
@@ -22,6 +23,13 @@ splunkhome = os.environ["SPLUNK_HOME"]
 sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))
 
 
+def get_uuid():
+    """
+    Function to return a unique uuid which is used to trace performance run_time of each subtask.
+    """
+    return str(uuid.uuid4())
+
+
 def remove_leading_spaces(text):
     """
     Remove leading spaces from each line of a variable
